{
  pkgs,
  agenix,
  disko,
  ...
}: {
  imports = [
    ./system.nix
    agenix.nixosModules.default
    disko.nixosModules.disko

    ./404.nix
    ./acme.nix
    ./bitwarden.nix
    ./borg.nix
    ./disk-config.nix
    ./forgejo.nix
    ./msmtp.nix
    ./murmur.nix
    ./nginx.nix
    ./upgrade.nix

    ../../users/maintainer
  ];

  age.identityPaths = ["/root/.ssh/id_agenix"];

  users = {
    mutableUsers = false;
    users.root.hashedPassword = "!";
  };

  environment.systemPackages = with pkgs; [
    git
    htop
    neovim
    tree
  ];

  services.syncthing.enable = true;

  systemd = {
    services.register-thing = {
      serviceConfig = {
        Type = "oneshot";
        User = "maintainer";
        ExecStart = "/home/maintainer/register-thing/thing";
      };
    };

    timers.register-thing = {
      wantedBy = ["timers.target"];
      timerConfig = {
        OnBootSec = "1m";
        OnUnitActiveSec = "1m";
        RandomizedDelaySec = "1m";
        Unit = "register-thing.service";
      };
    };
  };
}
